/*
* @Author: Bartuccio Antoine
* @Date:   2018-07-23 15:24:22
* @Last Modified by:   klmp200
* @Last Modified time: 2018-07-24 11:58:31
 */

package main

import (
	"./commands"
	"./settings"
	"./shared"
	tb "gopkg.in/tucnak/telebot.v2"
	"log"
	"time"
)

func main() {
	if err := settings.LoadSettings("settings.json", "settings_custom.json"); err != nil {
		log.Fatal(err)
	}

	log.Println("Initialize history")
	shared.InitHistory(int(settings.Settings["history size"].(float64)))

	log.Println("Bot initialisation")
	b, err := tb.NewBot(tb.Settings{
		Token:  settings.Settings["token"].(string),
		Poller: &tb.LongPoller{Timeout: 10 * time.Second},
	})
	if err != nil {
		log.Fatal(err)
		return
	}
	shared.Bot = b

	b.Handle("/hello", func(m *tb.Message) {
		b.Send(m.Chat, "Bonjour "+m.Sender.Username)
	})

	b.Handle(tb.OnText, func(m *tb.Message) {
		shared.History.AddMessage(m.Chat.ID, m.Text)
	})

	b.Handle("/sponge", commands.Sponge)

	b.Handle("/git", func(m *tb.Message) {
		b.Send(m.Chat, "Mon code est accessible librement à l'adresse https://git.klmp200.net/ALFRED/ALFRED. Venez contribuer :)")
	})

	b.Handle("/framapad", func(m *tb.Message) {
		b.Send(m.Chat, "Venez participer à mon développement en posant vos idées ici : https://mensuel.framapad.org/p/ALFRED2LERETOUR.")
	})

	log.Println("Starting bot")
	b.Start()
}
